using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;

namespace GridSample
{

	public class ButtonColumn : IGGridViewColumnDefinition
	{
		public ButtonColumn(String key) : base(key)
		{
		}

		public override IGGridViewCell CreateCell (IGGridView gridView, IGCellPath path, IGGridViewDataSourceHelper dataSource)
		{
			ButtonCell cell = (ButtonCell)gridView.DequeueReusableCell ("Bc");

			if (cell == null)
				cell = new ButtonCell ("Bc");


			return cell;
		}
	}

	public class ButtonCell : IGGridViewCell
	{
		UIButton _button;

		public ButtonCell (String identifier) : base (identifier)
		{
			_button = new UIButton (UIButtonType.Custom);
			_button.SetTitle ("Click Me", UIControlState.Normal);
			_button.SetTitleColor (UIColor.Black, UIControlState.Normal);
			_button.SetTitleColor (UIColor.Blue, UIControlState.Highlighted);
			_button.AddTarget (this, new MonoTouch.ObjCRuntime.Selector ("clicked"), UIControlEvent.TouchUpInside);
			this.AddSubview (_button);
		}

		[Export("clicked")]
		public void OnClick()
		{

		}

		public override void SetupSize (SizeF size)
		{
			base.SetupSize (size);

			float padding = 5;
			_button.Frame = new RectangleF (padding, padding, size.Width - padding * 2, size.Height - padding * 2);
		}

	}

	public partial class GridSampleViewController : UIViewController
	{
		public GridSampleViewController () : base ("GridSampleViewController", null)
		{

		
		}


		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			IGGridView grid = new IGGridView (this.View.Bounds, IGGridViewStyle.IGGridViewStyleDefault);
			grid.AutoresizingMask = UIViewAutoresizing.FlexibleDimensions;
			this.View.AddSubview (grid);
	


			IGGridViewDataSourceHelper dsh = new IGGridViewDataSourceHelper ();

			dsh.ColumnDefinitions.Add (new ButtonColumn ("temp"));
			dsh.Data = IGSalesmanItem.GenerateData (100).ToArray ();
			grid.DataSource = dsh;

		

		}
	}
}

